==> senior_design_system-0.17.0.tar.gz: lib/components/senior_colorful_header_structure/senior_colorful_header_structure.dart <==
import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';

import 'package:provider/provider.dart';
import 'package:senior_design_system/senior_themes.dart';

@Deprecated('Use SeniorBackdrop instead')
class SeniorColorfulHeaderStructure extends StatefulWidget {
  const SeniorColorfulHeaderStructure({
    Key? key,
    required this.title,
    required this.body,
    this.leading,
    this.actions,
    this.hasTopPadding = true,
    this.colors,
    this.onTapBack,
    this.hideLeading = false,
  }) : super(
          key: key,
        );

  final Widget title;
  final Widget? leading;
  final List<Widget>? actions;
  final Widget body;
  final bool hasTopPadding;
  final List<Color>? colors;
  final Function()? onTapBack;
  final bool hideLeading;

  @override
  State<SeniorColorfulHeaderStructure> createState() => _SeniorColorfulHeaderStructureState();
}

class _SeniorColorfulHeaderStructureState extends State<SeniorColorfulHeaderStructure> {
  @override
  Widget build(BuildContext context) {
    final SeniorTheme theme = Provider.of(context);
    final compAppTheme = theme.colorfulHeaderStructureTheme;
    final compDefaultTheme = seniorLightTheme.colorfulHeaderStructureTheme!;

    return Container(
      decoration: BoxDecoration(
        gradient: LinearGradient(
          colors: widget.colors ?? 
                  compAppTheme?.colors ?? 
                  compDefaultTheme.colors!,
        ),
      ),
      child: Column(
        children: [
          AppBar(
            leadingWidth: widget.hideLeading ? 0 : null,
            leading: widget.hideLeading
                ? SizedBox.shrink()
                : IconButton(
                    icon: const Icon(FontAwesomeIcons.angleLeft),
                    onPressed: widget.onTapBack ??
                        () {
                          Navigator.pop(context);
                        },
                  ),
            elevation: 0,
            backgroundColor: Colors.transparent,
            actions: widget.actions,
            title: widget.title,
            centerTitle: false,
          ),
          Expanded(
            child: Container(
              padding: EdgeInsets.only(
                top: widget.hasTopPadding ? SeniorRadius.huge : 0,
              ),
              decoration: BoxDecoration(
                borderRadius: BorderRadius.only(
                  topLeft: Radius.circular(
                    SeniorRadius.huge,
                  ),
                  topRight: Radius.circular(
                    SeniorRadius.huge,
                  ),
                ),
                color: SeniorColors.pureWhite,
              ),
              child: widget.body,
            ),
          )
        ],
      ),
    );
  }
}

==> senior_design_system-0.19.4.tar.gz: lib/components/senior_colorful_header_structure/senior_colorful_header_structure.dart <==
import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';

import 'package:provider/provider.dart';
import 'package:senior_design_system/senior_themes.dart';

@Deprecated('Use SeniorBackdrop instead')
class SeniorColorfulHeaderStructure extends StatefulWidget {
  const SeniorColorfulHeaderStructure({
    Key? key,
    required this.title,
    required this.body,
    this.leading,
    this.actions,
    this.hasTopPadding = true,
    this.colors,
    this.onTapBack,
    this.hideLeading = false,
  }) : super(
          key: key,
        );

  final Widget title;
  final Widget? leading;
  final List<Widget>? actions;
  final Widget body;
  final bool hasTopPadding;
  final List<Color>? colors;
  final Function()? onTapBack;
  final bool hideLeading;

  @override
  State<SeniorColorfulHeaderStructure> createState() => _SeniorColorfulHeaderStructureState();
}

class _SeniorColorfulHeaderStructureState extends State<SeniorColorfulHeaderStructure> {
  final _borderRadius = BorderRadius.only(
    topLeft: Radius.circular(
      SeniorRadius.huge,
    ),
    topRight: Radius.circular(
      SeniorRadius.huge,
    ),
  );

  @override
  Widget build(BuildContext context) {
    return Container(
      decoration: BoxDecoration(
        gradient: LinearGradient(
          colors: widget.colors ?? SeniorColors.primaryGradientColors,
        ),
      ),
      child: Column(
        children: [
          AppBar(
            leadingWidth: widget.hideLeading ? 0 : null,
            leading: widget.hideLeading
                ? SizedBox.shrink()
                : IconButton(
                    icon: const Icon(FontAwesomeIcons.angleLeft),
                    onPressed: widget.onTapBack ??
                        () {
                          Navigator.pop(context);
                        },
                  ),
            elevation: 0,
            backgroundColor: Colors.transparent,
            actions: widget.actions,
            title: widget.title,
            centerTitle: false,
          ),
          Expanded(
            child: Container(
              padding: EdgeInsets.only(
                top: widget.hasTopPadding ? SeniorRadius.huge : 0,
              ),
              decoration: BoxDecoration(
                borderRadius: _borderRadius,
                color: SeniorColors.pureWhite,
              ),
              child: ClipRRect(
                borderRadius: _borderRadius,
                child: widget.body,
              ),
            ),
          )
        ],
      ),
    );
  }
}
